@@ -22,8 +22,10 @@ extern "C"
 {
   extern int yylineno;
   int yylex(void);
+  int yylex_destroy(void);
   void yyerror (char const *mensagem);
   int yyparse ();
+  void paje_bison_parser_free();
   extern char *yytext;
   extern int yyleng;
   extern int yychar;
