@@ -20,6 +20,7 @@
 #include <iomanip>
 #include <exception>
 #include "PajeUnity.h"
+#include "PajeException.h"
 #include <argp.h>
 #include "libpaje_config.h"
 
@@ -324,21 +325,28 @@ int main (int argc, char **argv)
   bzero (&arguments, sizeof(struct arguments));
   arguments.start = arguments.end = arguments.stopat = -1;
   if (argp_parse (&argp, argc, argv, 0, 0, &arguments) == ARGP_KEY_ERROR){
-    fprintf(stderr, "%s, error during the parsing of parameters\n", argv[0]);
+    fprintf(stderr, "Error during the parsing of parameters\n");
     return 1;
   }
 
-  PajeUnity *unity = new PajeUnity (arguments.flex,
-				    !arguments.noStrict,
-				    arguments.input ? std::string(arguments.input) : std::string(),
-				    arguments.stopat,
-				    arguments.ignoreIncompleteLinks,
-				    arguments.probabilistic,
-                                    arguments.noImbrication,
-				    arguments.userDefined,
-				    arguments.outofcore,
-				    arguments.entityHierarchy,
-				    arguments.quiet);
+  PajeUnity *unity;
+  try {
+    unity = new PajeUnity (arguments.flex,
+			   !arguments.noStrict,
+			   arguments.input ? std::string(arguments.input) : std::string(),
+			   arguments.stopat,
+			   arguments.ignoreIncompleteLinks,
+			   arguments.probabilistic,
+			   arguments.noImbrication,
+			   arguments.userDefined,
+			   arguments.outofcore,
+			   arguments.entityHierarchy,
+			   arguments.quiet);
+  } catch (PajeException &e) {
+    e.report();
+    fprintf(stderr, "Error during the parsing of the input file\n");
+    return 1;
+  }
 
   if (arguments.time){
     printf ("%f\n", unity->getTime());
